# mi-amore


The initial goal of this package is get espresso (See https://ptolemy.berkeley.edu/projects/embedded/pubs/downloads/espresso/index.htm ) working again with python.

For me the great package here: 
https://github.com/cjdrake/pyeda
does not work. Then i found the package here:
https://github.com/Gigantua/Espresso
which compiles. I used the espresso code from there an try to implement an interface to python. 
The main work was understaning the inner logic of the espresso code.

Some ideas which i like to work on are:
- Document the Package, and share the findings here
- Implement an interface for simpy logic
- Implement an own minimimzer 
